@@ -27,9 +27,15 @@ from featuretools.computational_backends.utils import (
 from featuretools.entityset.relationship import RelationshipPath
 from featuretools.feature_base import AggregationFeature, FeatureBase
 from featuretools.utils import Trie
-from featuretools.utils.gen_utils import make_tqdm_iterator
+from featuretools.utils.gen_utils import (
+    import_or_none,
+    is_instance,
+    make_tqdm_iterator
+)
 from featuretools.variable_types import NumericTimeIndex
 
+ks = import_or_none('databricks.koalas')
+
 logger = logging.getLogger('featuretools.computational_backend')
 
 PBAR_FORMAT = "Elapsed: {elapsed} | Progress: {l_bar}{bar}"
@@ -125,6 +131,9 @@ def calculate_feature_matrix(features, entityset=None, cutoff_time=None, instanc
                 time_elapsed: total time in seconds that has elapsed since start of call
 
         include_cutoff_time (bool): Include data at cutoff times in feature calculations. Defaults to ``True``.
+
+    Returns:
+        pd.DataFrame: The feature matrix.
     """
     assert (isinstance(features, list) and features != [] and
             all([isinstance(feature, FeatureBase) for feature in features])), \
@@ -176,6 +185,8 @@ def calculate_feature_matrix(features, entityset=None, cutoff_time=None, instanc
 
         if isinstance(instance_ids, dd.Series):
             instance_ids = instance_ids.compute()
+        elif is_instance(instance_ids, ks, 'Series'):
+            instance_ids = instance_ids.to_pandas()
 
         # convert list or range object into series
         if not isinstance(instance_ids, pd.Series):
@@ -418,7 +429,7 @@ def calculate_chunk(cutoff_time, chunk_size, feature_set, entityset, approximate
                                                training_window=window,
                                                include_cutoff_time=include_cutoff_time)
 
-                if isinstance(_feature_matrix, dd.DataFrame):
+                if is_instance(_feature_matrix, (dd, ks), 'DataFrame'):
                     id_name = _feature_matrix.columns[-1]
                 else:
                     id_name = _feature_matrix.index.name
@@ -455,11 +466,18 @@ def calculate_chunk(cutoff_time, chunk_size, feature_set, entityset, approximate
                             pass_df = dd.from_pandas(pass_through[[id_name, 'time', col]], npartitions=_feature_matrix.npartitions)
                             _feature_matrix = _feature_matrix.merge(pass_df, how="outer")
                         _feature_matrix = _feature_matrix.drop(columns=['time'])
-
+                    elif is_instance(_feature_matrix, ks, 'DataFrame') and (len(pass_columns) > 0):
+                        _feature_matrix['time'] = time_last
+                        for col in pass_columns:
+                            pass_df = ks.from_pandas(pass_through[[id_name, 'time', col]])
+                            _feature_matrix = _feature_matrix.merge(pass_df, how="outer")
+                        _feature_matrix = _feature_matrix.drop(columns=['time'])
                 feature_matrix.append(_feature_matrix)
 
     if any(isinstance(fm, dd.DataFrame) for fm in feature_matrix):
         feature_matrix = dd.concat(feature_matrix)
+    elif any(is_instance(fm, ks, 'DataFrame') for fm in feature_matrix):
+        feature_matrix = ks.concat(feature_matrix)
     else:
         feature_matrix = pd.concat(feature_matrix)
 
@@ -566,8 +584,8 @@ def parallel_calculate_chunks(cutoff_time, chunk_size, feature_set, approximate,
                               save_progress, entityset, n_jobs, no_unapproximated_aggs,
                               cutoff_df_time_var, target_time, pass_columns,
                               progress_bar, dask_kwargs=None, progress_callback=None, include_cutoff_time=True):
-    from distributed import as_completed, Future
     from dask.base import tokenize
+    from distributed import Future, as_completed
 
     client = None
     cluster = None
