@@ -2,3 +2,7 @@ class UnknownFeature(Exception):
 
     def __init__(self, *args, **kwargs):
         Exception.__init__(self, *args, **kwargs)
+
+
+class UnusedPrimitiveWarning(UserWarning):
+    pass
