@@ -4,6 +4,7 @@ import pandas as pd
 from featuretools.primitives.base.transform_primitive_base import (
     TransformPrimitive
 )
+from featuretools.utils.gen_utils import Library
 from featuretools.variable_types import (
     Boolean,
     Datetime,
@@ -29,7 +30,7 @@ class GreaterThan(TransformPrimitive):
     name = "greater_than"
     input_types = [[Numeric, Numeric], [Datetime, Datetime], [Ordinal, Ordinal]]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK]
 
     def get_function(self):
         return np.greater
@@ -54,7 +55,7 @@ class GreaterThanScalar(TransformPrimitive):
     name = "greater_than_scalar"
     input_types = [[Numeric], [Datetime], [Ordinal]]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=0):
         self.value = value
@@ -84,7 +85,7 @@ class GreaterThanEqualTo(TransformPrimitive):
     name = "greater_than_equal_to"
     input_types = [[Numeric, Numeric], [Datetime, Datetime], [Ordinal, Ordinal]]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def get_function(self):
         return np.greater_equal
@@ -109,7 +110,7 @@ class GreaterThanEqualToScalar(TransformPrimitive):
     name = "greater_than_equal_to_scalar"
     input_types = [[Numeric], [Datetime], [Ordinal]]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=0):
         self.value = value
@@ -139,7 +140,7 @@ class LessThan(TransformPrimitive):
     name = "less_than"
     input_types = [[Numeric, Numeric], [Datetime, Datetime], [Ordinal, Ordinal]]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def get_function(self):
         return np.less
@@ -164,7 +165,7 @@ class LessThanScalar(TransformPrimitive):
     name = "less_than_scalar"
     input_types = [[Numeric], [Datetime], [Ordinal]]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=0):
         self.value = value
@@ -194,7 +195,7 @@ class LessThanEqualTo(TransformPrimitive):
     name = "less_than_equal_to"
     input_types = [[Numeric, Numeric], [Datetime, Datetime], [Ordinal, Ordinal]]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def get_function(self):
         return np.less_equal
@@ -219,7 +220,7 @@ class LessThanEqualToScalar(TransformPrimitive):
     name = "less_than_equal_to_scalar"
     input_types = [[Numeric], [Datetime], [Ordinal]]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=0):
         self.value = value
@@ -250,6 +251,7 @@ class Equal(TransformPrimitive):
     input_types = [Variable, Variable]
     return_type = Boolean
     commutative = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def get_function(self):
         def equal(x_vals, y_vals):
@@ -281,7 +283,7 @@ class EqualScalar(TransformPrimitive):
     name = "equal_scalar"
     input_types = [Variable]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=None):
         self.value = value
@@ -312,6 +314,7 @@ class NotEqual(TransformPrimitive):
     input_types = [Variable, Variable]
     return_type = Boolean
     commutative = True
+    compatibility = [Library.PANDAS, Library.DASK]
 
     def get_function(self):
         def not_equal(x_vals, y_vals):
@@ -343,7 +346,7 @@ class NotEqualScalar(TransformPrimitive):
     name = "not_equal_scalar"
     input_types = [Variable]
     return_type = Boolean
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=None):
         self.value = value
@@ -374,7 +377,7 @@ class AddNumeric(TransformPrimitive):
     input_types = [Numeric, Numeric]
     return_type = Numeric
     commutative = True
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def get_function(self):
         return np.add
@@ -398,7 +401,7 @@ class AddNumericScalar(TransformPrimitive):
     name = "add_numeric_scalar"
     input_types = [Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=0):
         self.value = value
@@ -433,7 +436,7 @@ class SubtractNumeric(TransformPrimitive):
     name = "subtract_numeric"
     input_types = [Numeric, Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK]
 
     def __init__(self, commutative=True):
         self.commutative = commutative
@@ -460,7 +463,7 @@ class SubtractNumericScalar(TransformPrimitive):
     name = "subtract_numeric_scalar"
     input_types = [Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=0):
         self.value = value
@@ -490,7 +493,7 @@ class ScalarSubtractNumericFeature(TransformPrimitive):
     name = "scalar_subtract_numeric_feature"
     input_types = [Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=0):
         self.value = value
@@ -525,7 +528,7 @@ class MultiplyNumeric(TransformPrimitive):
     ]
     return_type = Numeric
     commutative = True
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def get_function(self):
         return np.multiply
@@ -549,7 +552,7 @@ class MultiplyNumericScalar(TransformPrimitive):
     name = "multiply_numeric_scalar"
     input_types = [Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=1):
         self.value = value
@@ -581,7 +584,7 @@ class MultiplyBoolean(TransformPrimitive):
 
     return_type = Boolean
     commutative = True
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK]
 
     def get_function(self):
         return np.bitwise_and
@@ -611,7 +614,7 @@ class DivideNumeric(TransformPrimitive):
     name = "divide_numeric"
     input_types = [Numeric, Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, commutative=False):
         self.commutative = commutative
@@ -638,7 +641,7 @@ class DivideNumericScalar(TransformPrimitive):
     name = "divide_numeric_scalar"
     input_types = [Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=1):
         self.value = value
@@ -668,7 +671,7 @@ class DivideByFeature(TransformPrimitive):
     name = "divide_by_feature"
     input_types = [Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=1):
         self.value = value
@@ -698,7 +701,7 @@ class ModuloNumeric(TransformPrimitive):
     name = "modulo_numeric"
     input_types = [Numeric, Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def get_function(self):
         return np.mod
@@ -723,7 +726,7 @@ class ModuloNumericScalar(TransformPrimitive):
     name = "modulo_numeric_scalar"
     input_types = [Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=1):
         self.value = value
@@ -753,7 +756,7 @@ class ModuloByFeature(TransformPrimitive):
     name = "modulo_by_feature"
     input_types = [Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, value=1):
         self.value = value
@@ -784,7 +787,7 @@ class And(TransformPrimitive):
     input_types = [Boolean, Boolean]
     return_type = Boolean
     commutative = True
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def get_function(self):
         return np.logical_and
@@ -810,7 +813,7 @@ class Or(TransformPrimitive):
     input_types = [Boolean, Boolean]
     return_type = Boolean
     commutative = True
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def get_function(self):
         return np.logical_or
