@@ -44,8 +44,12 @@ from featuretools.primitives import (
 )
 from featuretools.tests.testing_utils import (
     backward_path,
-    get_mock_client_cluster
+    get_mock_client_cluster,
+    to_pandas
 )
+from featuretools.utils.gen_utils import Library, import_or_none
+
+ks = import_or_none('databricks.koalas')
 
 
 def test_scatter_warning(caplog):
@@ -60,8 +64,8 @@ def test_scatter_warning(caplog):
 
 # TODO: final assert fails w/ Dask
 def test_calc_feature_matrix(es):
-    if any(isinstance(entity.df, dd.DataFrame) for entity in es.entities):
-        pytest.xfail('Dask result not ordered')
+    if not all(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
+        pytest.xfail('Distributed dataframe result not ordered')
     times = list([datetime(2011, 4, 9, 10, 30, i * 6) for i in range(5)] +
                  [datetime(2011, 4, 9, 10, 31, i * 9) for i in range(4)] +
                  [datetime(2011, 4, 9, 10, 40, 0)] +
@@ -78,8 +82,6 @@ def test_calc_feature_matrix(es):
                                               es,
                                               cutoff_time=cutoff_time,
                                               verbose=True)
-    if isinstance(feature_matrix, dd.DataFrame):
-        feature_matrix = feature_matrix.compute().set_index('id').sort_index()
 
     assert (feature_matrix[property_feature.get_name()] == labels).values.all()
 
@@ -123,11 +125,9 @@ def test_calc_feature_matrix(es):
                                               es,
                                               cutoff_time=cutoff_reordered,
                                               verbose=True)
-    if isinstance(feature_matrix, dd.DataFrame):
-        feature_matrix = feature_matrix.compute().set_index('id').sort_index()
 
     assert all(feature_matrix.index == cutoff_reordered["id"].values)
-    # fails with Dask entitysets, cutoff time not reordered; cannot verify out of order
+    # fails with Dask and Koalas entitysets, cutoff time not reordered; cannot verify out of order
     # - can't tell if wrong/different all are false so can't check positional
 
 
@@ -165,8 +165,7 @@ def test_cfm_compose(es):
     )
 
     df = es['log'].df
-    if isinstance(df, dd.DataFrame):
-        df = df.compute()
+    df = to_pandas(df)
     labels = lm.search(
         df,
         num_examples_per_instance=-1
@@ -179,8 +178,7 @@ def test_cfm_compose(es):
                                               es,
                                               cutoff_time=labels,
                                               verbose=True)
-    if isinstance(feature_matrix, dd.DataFrame):
-        feature_matrix = feature_matrix.compute().set_index('id').sort_index()
+    feature_matrix = to_pandas(feature_matrix, index='id', sort_index=True)
 
     assert (feature_matrix[property_feature.get_name()] ==
             feature_matrix['label_func']).values.all()
@@ -297,9 +295,10 @@ def test_cfm_no_cutoff_time_index(pd_es):
 
 
 # TODO: fails with dask entitysets
+# TODO: fails with koalas entitysets
 def test_cfm_duplicated_index_in_cutoff_time(es):
-    if any(isinstance(entity.df, dd.DataFrame) for entity in es.entities):
-        pytest.xfail('Dask result not ordered, missing duplicates')
+    if not all(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
+        pytest.xfail('Distributed results not ordered, missing duplicates')
     times = [datetime(2011, 4, 1), datetime(2011, 5, 1),
              datetime(2011, 4, 1), datetime(2011, 5, 1)]
 
@@ -312,16 +311,13 @@ def test_cfm_duplicated_index_in_cutoff_time(es):
                                               es,
                                               cutoff_time=cutoff_time,
                                               chunk_size=1)
-    if isinstance(feature_matrix, dd.DataFrame):
-        feature_matrix = feature_matrix.compute().set_index('id').sort_index()
-
     assert (feature_matrix.shape[0] == cutoff_time.shape[0])
 
 
-# TODO: fails with Dask
+# TODO: fails with Dask, Koalas
 def test_saveprogress(es, tmpdir):
-    if any(isinstance(entity.df, dd.DataFrame) for entity in es.entities):
-        pytest.xfail('saveprogress fails with Dask')
+    if not all(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
+        pytest.xfail('saveprogress fails with distributed entitysets')
     times = list([datetime(2011, 4, 9, 10, 30, i * 6) for i in range(5)] +
                  [datetime(2011, 4, 9, 10, 31, i * 9) for i in range(4)] +
                  [datetime(2011, 4, 9, 10, 40, 0)] +
@@ -355,16 +351,13 @@ def test_saveprogress(es, tmpdir):
 
 
 def test_cutoff_time_correctly(es):
-    if any(isinstance(entity.df, dd.DataFrame) for entity in es.entities):
-        pytest.xfail('Dask result not ordered')
     property_feature = ft.Feature(es['log']['id'], parent_entity=es['customers'], primitive=Count)
     times = [datetime(2011, 4, 10), datetime(2011, 4, 11), datetime(2011, 4, 7)]
     cutoff_time = pd.DataFrame({'time': times, 'instance_id': [0, 1, 2]})
     feature_matrix = calculate_feature_matrix([property_feature],
                                               es,
                                               cutoff_time=cutoff_time)
-    if isinstance(feature_matrix, dd.DataFrame):
-        feature_matrix = feature_matrix.compute().set_index('id').sort_index()
+    feature_matrix = to_pandas(feature_matrix, index='id', sort_index=True)
     labels = [10, 5, 0]
     assert (feature_matrix[property_feature.get_name()] == labels).values.all()
 
@@ -425,8 +418,7 @@ def test_cutoff_time_columns_order(es):
                                                       cutoff_time=cutoff_time)
 
             labels = [10, 5, 0]
-            if isinstance(feature_matrix, dd.DataFrame):
-                feature_matrix = feature_matrix.compute().set_index('id').sort_index()
+            feature_matrix = to_pandas(feature_matrix, index='id', sort_index=True)
             assert (feature_matrix[property_feature.get_name()] == labels).values.all()
 
 
@@ -730,6 +722,7 @@ def test_training_window_recent_time_index(pd_es):
     assert (feature_matrix[dagg.get_name()] == dagg_values).values.all()
 
 
+# TODO: add test to fail w/ koalas
 def test_approximate_fails_dask(dask_es):
     agg_feat = ft.Feature(dask_es['log']['id'],
                           parent_entity=dask_es['sessions'],
@@ -1035,11 +1028,9 @@ def test_cutoff_time_naming(es):
     cutoff_df_wrong_time_name = cutoff_df.rename(columns={"time": "cutoff_time"})
 
     fm1 = calculate_feature_matrix([dfeat], es, cutoff_time=cutoff_df)
-    if isinstance(fm1, dd.DataFrame):
-        fm1 = fm1.compute().set_index('id').sort_index()
+    fm1 = to_pandas(fm1, index='id', sort_index=True)
     fm2 = calculate_feature_matrix([dfeat], es, cutoff_time=cutoff_df_index_name)
-    if isinstance(fm2, dd.DataFrame):
-        fm2 = fm2.compute().set_index('id').sort_index()
+    fm2 = to_pandas(fm2, index='id', sort_index=True)
     assert all((fm1 == fm2.values).values)
 
     error_text = 'Cutoff time DataFrame must contain a column with either the same name' \
@@ -1055,8 +1046,8 @@ def test_cutoff_time_naming(es):
 
 # TODO: order doesn't match, but output matches
 def test_cutoff_time_extra_columns(es):
-    if any(isinstance(entity.df, dd.DataFrame) for entity in es.entities):
-        pytest.xfail('Dask result not ordered')
+    if not all(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
+        pytest.xfail('Distributed result not ordered')
     agg_feat = ft.Feature(es['customers']['id'], parent_entity=es[u'régions'], primitive=Count)
     dfeat = DirectFeature(agg_feat, es['customers'])
 
@@ -1067,8 +1058,6 @@ def test_cutoff_time_extra_columns(es):
                               'label': [True, True, False]},
                              columns=['time', 'instance_id', 'label'])
     fm = calculate_feature_matrix([dfeat], es, cutoff_time=cutoff_df)
-    if isinstance(fm, dd.DataFrame):
-        fm = fm.compute()
     # check column was added to end of matrix
     assert 'label' == fm.columns[-1]
 
@@ -1102,20 +1091,17 @@ def test_instances_after_cutoff_time_removed(es):
                                   es,
                                   cutoff_time=cutoff_time,
                                   cutoff_time_in_index=True)
-    if isinstance(fm, dd.DataFrame):
-        fm = fm.compute().set_index('id')
-        actual_ids = fm.index
-    else:
-        actual_ids = [id for (id, _) in fm.index]
+    fm = to_pandas(fm, index='id', sort_index=True)
+    actual_ids = [id for (id, _) in fm.index] if isinstance(fm.index, pd.MultiIndex) else fm.index
 
     # Customer with id 1 should be removed
     assert set(actual_ids) == set([2, 0])
 
 
-# TODO: Dask doesn't keep instance_id after cutoff
+# TODO: Dask and Koalas do not keep instance_id after cutoff
 def test_instances_with_id_kept_after_cutoff(es):
-    if any(isinstance(entity.df, dd.DataFrame) for entity in es.entities):
-        pytest.xfail('Dask result not ordered, missing extra instances')
+    if not all(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
+        pytest.xfail('Distributed result not ordered, missing extra instances')
     property_feature = ft.Feature(es['log']['id'], parent_entity=es['customers'], primitive=Count)
     cutoff_time = datetime(2011, 4, 8)
     fm = calculate_feature_matrix([property_feature],
@@ -1126,18 +1112,15 @@ def test_instances_with_id_kept_after_cutoff(es):
 
     # Customer #1 is after cutoff, but since it is included in instance_ids it
     # should be kept.
-    if isinstance(fm, dd.DataFrame):
-        fm = fm.compute().set_index('id')
-        actual_ids = fm.index
-    else:
-        actual_ids = [id for (id, _) in fm.index]
+    actual_ids = [id for (id, _) in fm.index] if isinstance(fm.index, pd.MultiIndex) else fm.index
     assert set(actual_ids) == set([0, 1, 2])
 
 
 # TODO: Fails with Dask
+# TODO: Fails with Koalas
 def test_cfm_returns_original_time_indexes(es):
-    if any(isinstance(entity.df, dd.DataFrame) for entity in es.entities):
-        pytest.xfail('Dask result not ordered, indexes are lost due to not multiindexing')
+    if not all(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
+        pytest.xfail('Distributed result not ordered, indexes are lost due to not multiindexing')
     agg_feat = ft.Feature(es['customers']['id'], parent_entity=es[u'régions'], primitive=Count)
     dfeat = DirectFeature(agg_feat, es['customers'])
     cutoff_df = pd.DataFrame({'time': [pd.Timestamp('2011-04-09 10:30:06'),
@@ -1148,14 +1131,10 @@ def test_cfm_returns_original_time_indexes(es):
     fm = calculate_feature_matrix([dfeat],
                                   es, cutoff_time=cutoff_df,
                                   cutoff_time_in_index=True)
-    if isinstance(fm, dd.DataFrame):
-        fm = fm.compute().set_index('id')
-        instance_level_vals = fm.index
-        # Dask doesn't return time (doesn't support multi-index)
-        time_level_vals = []
-    else:
-        instance_level_vals = fm.index.get_level_values(0).values
-        time_level_vals = fm.index.get_level_values(1).values
+
+    instance_level_vals = fm.index.get_level_values(0).values
+    time_level_vals = fm.index.get_level_values(1).values
+
     assert (instance_level_vals == cutoff_df['instance_id'].values).all()
     assert (time_level_vals == cutoff_df['time'].values).all()
 
@@ -1535,9 +1514,10 @@ def test_string_time_values_in_cutoff_time(es):
 
 
 # TODO: Dask version fails (feature matrix is empty)
+# TODO: Koalas version fails (koalas groupby agg doesn't support custom functions)
 def test_no_data_for_cutoff_time(mock_customer):
-    if any(isinstance(entity.df, dd.DataFrame) for entity in mock_customer.entities):
-        pytest.xfail('Dask version fails, returned feature matrix is empty')
+    if not all(isinstance(entity.df, pd.DataFrame) for entity in mock_customer.entities):
+        pytest.xfail("Dask fails because returned feature matrix is empty; Koalas doesn't support custom agg functions")
     es = mock_customer
     cutoff_times = pd.DataFrame({"customer_id": [4],
                                  "time": pd.Timestamp('2011-04-08 20:08:13')})
@@ -1547,15 +1527,13 @@ def test_no_data_for_cutoff_time(mock_customer):
     features = [trans_per_customer, ft.Feature(trans_per_session, parent_entity=es["customers"], primitive=Max)]
 
     fm = ft.calculate_feature_matrix(features, entityset=es, cutoff_time=cutoff_times)
-    if isinstance(fm, dd.DataFrame):
-        fm = fm.compute().set_index('customer_id')
 
     # due to default values for each primitive
     # count will be 0, but max will nan
     np.testing.assert_array_equal(fm.values, [[0, np.nan]])
 
 
-# adding missing instances not supported in Dask
+# adding missing instances not supported in Dask or Koalas
 def test_instances_not_in_data(pd_es):
     last_instance = max(pd_es['log'].df.index.values)
     instances = list(range(last_instance + 1, last_instance + 11))
@@ -1750,7 +1728,7 @@ def test_closes_tqdm(es):
         name = "error_prim"
         input_types = [ft.variable_types.Numeric]
         return_type = "Numeric"
-        dask_compatible = True
+        compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
         def get_function(self):
             def error(s):
@@ -1830,6 +1808,5 @@ def test_calc_feature_matrix_with_cutoff_df_and_instance_ids(es):
                                                   instance_ids=[1, 3, 5],
                                                   verbose=True)
 
-    if isinstance(feature_matrix, dd.DataFrame):
-        feature_matrix = feature_matrix.compute()
+    feature_matrix = to_pandas(feature_matrix)
     assert (feature_matrix[property_feature.get_name()] == labels).values.all()
