@@ -3,14 +3,19 @@ from datetime import datetime
 import numpy as np
 import pandas as pd
 import pytest
-from dask import dataframe as dd
 
 import featuretools as ft
 from featuretools import variable_types
 from featuretools.entityset import Entity, EntitySet
-from featuretools.tests.testing_utils import make_ecommerce_entityset
+from featuretools.tests.testing_utils import (
+    make_ecommerce_entityset,
+    to_pandas
+)
+from featuretools.utils.gen_utils import import_or_none
 from featuretools.variable_types import find_variable_types
 
+ks = import_or_none('databricks.koalas')
+
 
 def test_enforces_variable_id_is_str(es):
     assert variable_types.Categorical("1", es["customers"])
@@ -60,7 +65,7 @@ def test_eq(es):
 
     assert es['log'].__eq__(es['log'], deep=True)
     assert es['log'].__eq__(other_es['log'], deep=True)
-    assert all(es['log'].df['latlong'].eq(latlong))
+    assert all(to_pandas(es['log'].df['latlong']).eq(to_pandas(latlong)))
 
     other_es['log'].add_interesting_values()
     assert not es['log'].__eq__(other_es['log'], deep=True)
@@ -82,7 +87,10 @@ def test_eq(es):
 
 def test_update_data(es):
     df = es['customers'].df.copy()
-    df['new'] = pd.Series([1, 2, 3])
+    if ks and isinstance(df, ks.DataFrame):
+        df['new'] = [1, 2, 3]
+    else:
+        df['new'] = pd.Series([1, 2, 3])
 
     error_text = 'Updated dataframe is missing new cohort column'
     with pytest.raises(ValueError, match=error_text):
@@ -94,35 +102,34 @@ def test_update_data(es):
 
     # test already_sorted on entity without time index
     df = es["sessions"].df.copy()
-    if isinstance(df, dd.DataFrame):
-        updated_id = df['id'].compute()
+    updated_id = to_pandas(df['id'])
+    updated_id.iloc[1] = 2
+    updated_id.iloc[2] = 1
+
+    if ks and isinstance(df, ks.DataFrame):
+        df["id"] = updated_id.to_list()
+        df = df.sort_index()
     else:
-        updated_id = df['id']
-    updated_id.iloc[1:3] = [2, 1]
-    df["id"] = updated_id
+        df["id"] = updated_id
     es["sessions"].update_data(df.copy())
-    sessions_df = es['sessions'].df
-    if isinstance(sessions_df, dd.DataFrame):
-        sessions_df = sessions_df.compute()
+    sessions_df = to_pandas(es['sessions'].df)
     assert sessions_df["id"].iloc[1] == 2  # no sorting since time index not defined
     es["sessions"].update_data(df.copy(), already_sorted=True)
-    sessions_df = es['sessions'].df
-    if isinstance(sessions_df, dd.DataFrame):
-        sessions_df = sessions_df.compute()
+    sessions_df = to_pandas(es['sessions'].df)
     assert sessions_df["id"].iloc[1] == 2
 
     # test already_sorted on entity with time index
     df = es["customers"].df.copy()
-    if isinstance(df, dd.DataFrame):
-        updated_signup = df['signup_date'].compute()
-    else:
-        updated_signup = df['signup_date']
+    updated_signup = to_pandas(df['signup_date'])
     updated_signup.iloc[0] = datetime(2011, 4, 11)
-    df['signup_date'] = updated_signup
+
+    if ks and isinstance(df, ks.DataFrame):
+        df['signup_date'] = updated_signup.to_list()
+        df = df.sort_index()
+    else:
+        df['signup_date'] = updated_signup
     es["customers"].update_data(df.copy(), already_sorted=True)
-    customers_df = es['customers'].df
-    if isinstance(customers_df, dd.DataFrame):
-        customers_df = customers_df.compute()
+    customers_df = to_pandas(es['customers'].df)
     assert customers_df["id"].iloc[0] == 2
 
     # only pandas allows for sorting:
@@ -151,9 +158,8 @@ def test_query_by_values_secondary_time_index(es):
     end = np.datetime64(datetime(2011, 10, 1))
     all_instances = [0, 1, 2]
     result = es['customers'].query_by_values(all_instances, time_last=end)
+    result = to_pandas(result, index='id')
 
-    if isinstance(result, dd.DataFrame):
-        result = result.compute().set_index('id')
     for col in ["cancel_date", "cancel_reason"]:
         nulls = result.loc[all_instances][col].isnull() == [False, True, True]
         assert nulls.all(), "Some instance has data it shouldn't for column %s" % col
@@ -171,6 +177,17 @@ def test_delete_variables(es):
         assert var not in entity.df.columns
 
 
+def test_delete_variables_string_input(es):
+    entity = es['customers']
+    with pytest.raises(TypeError, match='variable_ids must be a list of variable names'):
+        entity.delete_variables('age')
+
+    variable_names = [v.id for v in entity.variables]
+
+    assert 'age' in variable_names
+    assert 'age' in entity.df.columns
+
+
 def test_variable_types_unmodified():
     df = pd.DataFrame({"id": [1, 2, 3, 4, 5, 6],
                        "transaction_time": [10, 12, 13, 20, 21, 20],
