@@ -26,6 +26,7 @@ from featuretools.primitives import (
     get_transform_primitives
 )
 from featuretools.primitives.utils import _get_descriptions
+from featuretools.utils.gen_utils import Library
 
 
 def test_list_primitives_order():
@@ -39,7 +40,7 @@ def test_list_primitives_order():
         actual_desc = _get_descriptions([primitive])[0]
         if actual_desc:
             assert actual_desc == row['description']
-        assert row['dask_compatible'] == primitive.dask_compatible
+        assert row['dask_compatible'] == (Library.DASK in primitive.compatibility)
 
     types = df['type'].values
     assert 'aggregation' in types
