@@ -1,12 +1,13 @@
 import numpy as np
 import pandas as pd
 
-from featuretools.utils.gen_utils import camel_to_snake, find_descendents
+from featuretools.utils.gen_utils import camel_to_snake
 
 
 class ClassNameDescriptor(object):
     """Descriptor to convert a class's name from camelcase to snakecase
     """
+
     def __get__(self, instance, class_):
         return camel_to_snake(class_.__name__)
 
@@ -404,11 +405,6 @@ class FilePath(Variable):
     _default_pandas_dtype = str
 
 
-def find_variable_types():
-    return {vtype.type_string: vtype for vtype in find_descendents(Variable)
-            if vtype != Variable}
-
-
 DEFAULT_DTYPE_VALUES = {
     np.datetime64: pd.Timestamp.now(),
     int: 0,
